@@ -1,5 +1,5 @@
-import logging
 import io
+import logging
 import sys
 import tarfile
 import time
@@ -12,15 +12,14 @@ import click
 import docker  # type: ignore
 from testcontainers.core.generic import DockerContainer  # type: ignore
 
-from pytezos.logging import DEFAULT_LOGGING_CONFIG
 from pytezos import ContractInterface, __version__, pytezos
 from pytezos.cli.github import create_deployment, create_deployment_status
 from pytezos.context.mixin import default_network  # type: ignore
-from pytezos.logging import logger
+from pytezos.logging import DEFAULT_LOGGING_CONFIG, logger
 from pytezos.michelson.types.base import generate_pydoc
 from pytezos.operation.result import OperationResult
 from pytezos.rpc.errors import RpcError
-from pytezos.sandbox.node import DOCKER_IMAGE, TEZOS_NODE_PORT, SandboxedNodeContainer
+from pytezos.sandbox.node import DOCKER_IMAGE, TEZOS_NODE_PORT, SandboxedNodeContainer, get_next_baker_key
 from pytezos.sandbox.parameters import EDO, FLORENCE, HANGZHOU, ITHACA
 
 kernel_js_path = join(dirname(dirname(__file__)), 'assets', 'kernel.js')
@@ -350,7 +349,7 @@ def sandbox(
         while True:
             try:
                 logger.info('Baking block %s...', blocks_baked)
-                block_hash = node.bake()
+                block_hash = node.bake(key=get_next_baker_key(node.client))
                 logger.info('Baked block: %s', block_hash)
                 blocks_baked += 1
                 if blocks and blocks_baked == blocks:
