@@ -1,4 +1,3 @@
-import logging
 import logging.config
 
 DEFAULT_LOGGING_CONFIG = {
@@ -23,8 +22,4 @@ DEFAULT_LOGGING_CONFIG = {
     }
 }
 
-
-if not logging.getLogger().hasHandlers():
-    logging.config.dictConfig(DEFAULT_LOGGING_CONFIG)
-
 logger = logging.getLogger('pytezos')
