@@ -179,7 +179,7 @@ class OrType(MichelsonType, ADTMixin, prim='or', args_len=2):
         if self.is_enum:
             return entrypoint  # type: ignore
         else:
-            py_obj = flat_values[entrypoint].to_python_object(try_unpack=try_unpack, lazy_diff=lazy_diff)
+            py_obj = flat_values[entrypoint].to_python_object(try_unpack=try_unpack, lazy_diff=lazy_diff, comparable=comparable)
             return (entrypoint, py_obj) if comparable else {entrypoint: py_obj}
 
     def merge_lazy_diff(self, lazy_diff: List[dict]) -> 'OrType':
