@@ -77,8 +77,6 @@ class OperationGroup(ContextMixin, ContentMixin):
 
     def binary_payload(self) -> bytes:
         """Get binary payload used for injection/hash calculation."""
-        if self.contents[0]['kind'] == 'endorsement_with_slot':
-            return bytes.fromhex(self.forge()) + b'\x00' * 64
         if not self.signature:
             raise ValueError('Not signed')
 
@@ -124,6 +122,7 @@ class OperationGroup(ContextMixin, ContentMixin):
         protocol = self.protocol or self.context.get_protocol()
         branch = self.branch or self.shell.blocks[f'head~{MAX_OPERATIONS_TTL - ttl}'].hash()
         source = self.key.public_key_hash()
+        constants = self.shell.head.context.constants()
 
         if counter is not None:
             self.context.set_counter(counter - 1)  # which is supposedly the current state (head)
@@ -136,10 +135,8 @@ class OperationGroup(ContextMixin, ContentMixin):
             'secret': lambda x: self.key.activation_code,
             'period': lambda x: str(self.shell.head.voting_period()),
             'public_key': lambda x: self.key.public_key(),
-            'gas_limit': lambda x: str(gas_limit) if gas_limit is not None else str(default_gas_limit(x, self.context.constants)),
-            'storage_limit': lambda x: str(storage_limit)
-            if storage_limit is not None
-            else str(default_storage_limit(x, self.context.constants)),
+            'gas_limit': lambda x: str(gas_limit) if gas_limit is not None else str(default_gas_limit(x, constants)),
+            'storage_limit': lambda x: str(storage_limit) if storage_limit is not None else str(default_storage_limit(x, constants)),
             'fee': lambda x: str(default_fee(x, gas_limit, minimal_nanotez_per_gas_unit)),
         }
 
@@ -239,6 +236,7 @@ class OperationGroup(ContextMixin, ContentMixin):
             raise RpcError.from_errors(OperationResult.errors(opg_with_metadata))
 
         extra_size = (32 + 64) // len(opg.contents) + 1  # size of serialized branch and signature
+        counter_offset = self.context.get_counter_offset()
 
         def fill_content(content: Dict[str, Any]) -> Dict[str, Any]:
             if validation_passes[content['kind']] == 3:
@@ -264,7 +262,7 @@ class OperationGroup(ContextMixin, ContentMixin):
                     gas_limit=str(_gas_limit),
                     storage_limit=str(_storage_limit),
                     fee=str(_fee),
-                    counter=str(current_counter + self.context.get_counter_offset()),
+                    counter=str(current_counter + counter_offset),
                 )
 
             content.pop('metadata')
@@ -425,32 +423,3 @@ class OperationGroup(ContextMixin, ContentMixin):
         :rtype: List[OperationResult]
         """
         return OperationResult.from_operation_group(self.preapply())
-
-    def with_slot(self) -> 'OperationGroup':
-        """Wrap endorsement operation
-
-        :rtype: OperationGroup
-        """
-        if self.contents[0]['kind'] != 'endorsement':
-            raise NotImplementedError('Works for endorsement only')
-        if self.branch is None:
-            raise ValueError('Do .fill() first')
-        if self.signature is None:
-            raise ValueError('Do .sign() first')
-
-        level = int(self.contents[0]['level'])
-        delegate = self.key.public_key_hash()
-        rights = self.shell.head.helpers.endorsing_rights(level=level, delegate=delegate)
-        if len(rights) != 1:
-            raise ValueError(f'No endorsing rights for delegate `{delegate}` at level `{level}`')
-
-        slot = rights[0]['slots'][0]
-        endorsement = {'branch': self.branch, 'operations': {'kind': 'endorsement', 'level': level}, 'signature': self.signature}
-
-        return OperationGroup(
-            context=self.context,
-            branch=self.branch,
-            chain_id=self.chain_id,
-            protocol=self.protocol,
-            contents=[ContentMixin().endorsement_with_slot(endorsement=endorsement, slot=slot)],
-        )
