@@ -11,6 +11,7 @@ from deprecation import deprecated  # type: ignore
 from pytezos.crypto.encoding import base58_decode
 from pytezos.jupyter import get_attr_docstring
 from pytezos.logging import logger
+from pytezos.rpc.errors import ReorgError
 from pytezos.rpc.kind import validation_passes
 from pytezos.rpc.protocol import BlockQuery, BlocksQuery
 from pytezos.rpc.query import RpcQuery
@@ -66,26 +67,22 @@ class ShellQuery(RpcQuery, path=''):
         self,
         current_block_hash: str,
         max_blocks: int = 1,
-        max_priority: int = 2,
         yield_current=False,
         time_between_blocks: Optional[int] = None,
         block_timeout: Optional[int] = None,
     ) -> Generator[str, None, None]:
-        """Iterates over future blocks (waits and yields block hash)
+        """Iterates over future blocks (waits and yields block hash), handles reorgs
 
         :param current_block_hash: hash of the current block (head)
         :param max_blocks: number of blocks to iterate (not including the current one)
-        :param max_priority: wait for blocks with lower priority (increased timeout)
         :param yield_current: yield current block hash at the very beginning
         :param time_between_blocks: override protocol constant
         :param block_timeout: set block timeout (by default Pytezos will wait for a long time)
         :return: block hashes
         """
-        prev_block_hash: Optional[str] = None
-
         if time_between_blocks is None:
             constants = self.blocks[current_block_hash].context.constants()
-            time_between_blocks = int(constants.get('minimal_block_delay', constants['time_between_blocks'][0]))
+            time_between_blocks = int(constants.get('minimal_block_delay', 0))
 
         if block_timeout is None:
             block_timeout = MAX_BLOCK_TIMEOUT
@@ -93,12 +90,12 @@ class ShellQuery(RpcQuery, path=''):
         if yield_current:
             yield current_block_hash
 
-        for _ in range(max_blocks):
-            header = self.blocks[current_block_hash].header()
-            if prev_block_hash and prev_block_hash != header['predecessor']:
-                raise StopIteration('Reorg detected, expected predecessor %s instead of %s', prev_block_hash, header['predecessor'])
+        current_header = self.blocks[current_block_hash].header()
+        max_level = current_header['level'] + max_blocks
 
-            prev_block_dt = datetime.strptime(header['timestamp'], '%Y-%m-%dT%H:%M:%SZ')
+        while current_header['level'] < max_level:
+            logger.info('Current level: %d (max %d)', current_header['level'], max_level)
+            prev_block_dt = datetime.strptime(current_header['timestamp'], '%Y-%m-%dT%H:%M:%SZ')
             elapsed_sec = (datetime.utcnow() - prev_block_dt).seconds
             sleep_sec = 1 if elapsed_sec > time_between_blocks else (time_between_blocks - elapsed_sec + 1)
 
@@ -118,8 +115,8 @@ class ShellQuery(RpcQuery, path=''):
             if current_block_hash != next_block_hash:
                 assert next_block_hash
                 yield next_block_hash
-                prev_block_hash = current_block_hash
                 current_block_hash = next_block_hash
+                current_header = self.blocks[current_block_hash].header()
             else:
                 raise TimeoutError('Reached timeout (%d sec) while waiting for the next block', block_timeout)
 
@@ -168,14 +165,15 @@ class ShellQuery(RpcQuery, path=''):
                             logger.info('Operation %s has left mempool', opg_hash)
                             pending.remove(opg_hash)
 
-            if len(pending) < len(opg_hashes):
-                included = self.blocks[block_hash].operation_hashes()
-                for i, vp in enumerate(included):
-                    for j, opg_hash in enumerate(vp):
-                        if opg_hash in opg_hashes and opg_hash not in confirmations:
-                            logger.info('Operation %s has been included to block %s', opg_hash, block_hash)
-                            confirmations[opg_hash] = 0  # initialize
-                            operations.append(self.blocks[block_hash].operations[i][j]())
+            included = self.blocks[block_hash].operation_hashes()
+            for i, vp in enumerate(included):
+                for j, opg_hash in enumerate(vp):
+                    if opg_hash in opg_hashes and opg_hash not in confirmations:
+                        logger.info('Operation %s has been included to block %s', opg_hash, block_hash)
+                        if opg_hash in pending:  # can be still in the particular node's mempool (not yet removed)
+                            pending.remove(opg_hash)
+                        confirmations[opg_hash] = 0  # initialize
+                        operations.append(self.blocks[block_hash].operations[i][j]())
 
             for opg_hash in confirmations:
                 confirmations[opg_hash] += 1
@@ -210,7 +208,7 @@ class ShellQuery(RpcQuery, path=''):
         :param delay_sec: Sleep delay
         """
         if time_between_blocks is None:
-            time_between_blocks = int(self.block.context.constants()["time_between_blocks"][0])  # type: ignore
+            time_between_blocks = int(self.block.context.constants()["minimal_block_delay"])  # type: ignore
 
         if time_between_blocks > 0:
             if prev_hash is None:
